@@ -29,9 +29,15 @@
  */
 
 extern "C" {
-#include "meta_modelica.h"
+#include "meta/meta_modelica.h"
+
 #define ADD_METARECORD_DEFINITIONS static
-#include "OpenModelicaBootstrappingHeader.h"
+#if defined(OMC_BOOTSTRAPPING)
+  #include "../boot/tarball-include/OpenModelicaBootstrappingHeader.h"
+#else
+  #include "../OpenModelicaBootstrappingHeader.h"
+#endif
+
 }
 #include "ptolemyio.cpp"
 
