@@ -40,7 +40,7 @@ class LoggerXMLTCP: public LoggerXML
  protected:
   LoggerXMLTCP(std::string host, int port, LogSettings &logSettings)
     : LoggerXML(logSettings, true, _sstream)
-    , _endpoint(boost::asio::ip::address::from_string(host), port)
+    , _endpoint(boost::asio::ip::make_address(host), port)
     , _socket(_ios)
   {
     if (logSettings.format != LF_XML && logSettings.format != LF_XMLTCP) {
@@ -82,7 +82,7 @@ class LoggerXMLTCP: public LoggerXML
     }
   }
 
-  boost::asio::io_service _ios;
+  boost::asio::io_context _ios;
   boost::asio::ip::tcp::endpoint _endpoint;
   boost::asio::ip::tcp::socket _socket;
   std::stringstream _sstream;
@@ -557,6 +557,7 @@ vector<const char *> OMCFactory::handleComplexCRuntimeArguments(int argc, const
       else if ((oit = opts.find(arg)) != opts.end() && i < argc - 1)
           opts[oit->first] = argv[++i]; // regular override
       else if (strncmp(argv[i], "-override=", 10) == 0) {
+          // FIXME startTime, stopTime, ... are no longer used with override
           map<string, string> supported = MAP_LIST_OF
             "startTime", "-S" MAP_LIST_SEP "stopTime", "-E" MAP_LIST_SEP
             "stepSize", "-H" MAP_LIST_SEP "numberOfIntervals", "-G" MAP_LIST_SEP
