@@ -334,6 +334,7 @@ private:
     const StringAnnotation &getTab() const {return mTab;}
     const StringAnnotation &getGroup() const {return mGroup;}
     const BooleanAnnotation &isEnabled() const {return mEnable;}
+    bool hasShowStartAttribute() const {return mHasShowStartAttribute;}
     const BooleanAnnotation &getShowStartAttribute() const {return mShowStartAttribute;}
     const BooleanAnnotation &isColorSelector() const {return mColorSelector;}
     const Selector &getLoadSelector() const {return mLoadSelector;}
@@ -345,6 +346,7 @@ private:
     StringAnnotation mTab;
     StringAnnotation mGroup;
     BooleanAnnotation mEnable;
+    bool mHasShowStartAttribute = false;
     BooleanAnnotation mShowStartAttribute;
     BooleanAnnotation mColorSelector;
     Selector mLoadSelector;
@@ -365,6 +367,7 @@ private:
     bool isCheckBox() const {return mCheckBox;}
     bool isDymolaCheckBox() const {return mDymolaCheckBox;}
     const QList<Modifier*> &getChoices() const {return mChoices;}
+    QStringList getChoicesDisplayStringList() const;
     QStringList getChoicesValueStringList() const;
     QStringList getChoicesCommentStringList() const;
   private:
@@ -486,7 +489,7 @@ private:
     const QString &getType() const {return mType;}
     QString getValueWithoutQuotes() const {return StringHandler::removeFirstLastQuotes(getValue());}
     bool isValueDefined() const {return mValueDefined;}
-    QString toString(bool skipTopLevel = false, bool includeComment = false) const;
+    QString toString(bool skipTopLevel = false, bool includeComment = false, bool onlyType = false) const;
     Modifier *getModifier(const QString &modifier) const;
     QPair<QString, bool> getModifierValue(const QString &modifier) const;
     bool hasModifier(const QString &modifier) const;
@@ -499,6 +502,7 @@ private:
     bool isReplaceable() const;
     const QString &getValue() const {return mValue;}
     const QString &getComment() const {return mComment;}
+    bool hasElement() const {return mpElement != 0;}
     QPair<QString, bool> getModifierValue(QStringList qualifiedModifierName) const;
   private:
     Model *mpParentModel;
@@ -608,10 +612,12 @@ private:
     bool isModelJsonEmpty() const {return mModelJson.isEmpty();}
     void setModelJson(const QJsonObject &modelJson) {mModelJson = modelJson;}
     const QString &getName() const {return mName;}
+    QString getNameIfReplaceable() const;
     const QString &getRootType() const;
     bool isMissing() const {return mMissing;}
     void setRestriction(const QString &restriction) {mRestriction = restriction;}
     const QString &getRestriction() const {return mRestriction;}
+    Replaceable *getReplaceable() const;
     bool isConnector() const;
     bool isExpandableConnector() const;
     bool isEnumeration() const;
@@ -643,10 +649,10 @@ private:
     bool isParameterConnectorSizing(const QString &parameter);
     bool isValidConnection(const Name &lhsConnector, const Name &rhsConnector) const;
     bool isTypeCompatibleWith(const Model &other, bool lhsOutside, bool rhsOutside) const;
-    QPair<QString, bool> getParameterValue(const QString &parameter, QString &typeName);
-    QPair<QString, bool> getParameterValueFromExtendsModifiers(const QStringList &parameter);
+    QPair<QString, bool> getVariableValue(QStringList variables);
+    QString getVariableType(QStringList variables);
 
-    FlatModelica::Expression* getVariableBinding(const QString &variableName);
+    FlatModelica::Expression* getVariableValueOrBinding(const QString &variableName, bool value) const;
     const Element *lookupElement(const QString &name) const;
     Element *lookupElement(const QString &name);
     const Element *lookupElement(const Name &name) const;
@@ -686,12 +692,15 @@ private:
     void setModel(Model *pModel) {mpModel = pModel;}
     Model *getModel() const {return mpModel;}
     Modifier *getModifier() const {return mpModifier;}
+    QPair<QString, bool> getVariableValue(QStringList variables);
     QPair<QString, bool> getModifierValueFromType(QStringList modifierNames);
     const Dimensions &getDimensions() const {return mDims;}
     bool isPublic() const;
     bool isFinal() const;
     bool isInner() const;
     bool isOuter() const;
+    bool isParameter() const;
+    bool isInput() const;
     Replaceable *getReplaceable() const;
     bool isRedeclare() const;
     bool isConnector() const;
@@ -701,6 +710,8 @@ private:
     QString getDirectionPrefix() const;
     const QString &getComment() const;
     Annotation *getAnnotation() const;
+    const FlatModelica::Expression &getValue() const {return mValue;}
+    FlatModelica::Expression &getValue() {return mValue;}
     const FlatModelica::Expression &getBinding() const {return mBinding;}
     FlatModelica::Expression &getBinding() {return mBinding;}
     void setBinding(const FlatModelica::Expression expression) {mBinding = expression;}
@@ -718,7 +729,7 @@ private:
     virtual bool isComponent() const = 0;
     virtual bool isExtend() const = 0;
     virtual bool isClass() const = 0;
-    virtual QString toString(bool skipTopLevel = false, bool mergeExtendsModifiers = false) const;
+    virtual QString toString(bool skipTopLevel = false, bool mergeExtendsModifiers = false, bool includeComment = true) const;
 
     QString getDirection() const;
   private:
@@ -733,6 +744,7 @@ private:
     std::unique_ptr<Prefixes> mpPrefixes;
     QString mComment;
     std::unique_ptr<Annotation> mpAnnotation;
+    FlatModelica::Expression mValue;
     FlatModelica::Expression mBinding;
     FlatModelica::Expression mBindingForReset;
   };
@@ -756,7 +768,7 @@ private:
     virtual bool isComponent() const override {return false;}
     virtual bool isExtend() const override {return true;}
     virtual bool isClass() const override {return false;}
-    virtual QString toString(bool skipTopLevel = false, bool mergeExtendsModifiers = false) const override;
+    virtual QString toString(bool skipTopLevel = false, bool mergeExtendsModifiers = false, bool includeComment = true) const override;
   };
 
   class Component : public Element
@@ -788,7 +800,7 @@ private:
     virtual bool isComponent() const override {return true;}
     virtual bool isExtend() const override {return false;}
     virtual bool isClass() const override {return false;}
-    virtual QString toString(bool skipTopLevel = false, bool mergeExtendsModifiers = false) const override;
+    virtual QString toString(bool skipTopLevel = false, bool mergeExtendsModifiers = false, bool includeComment = true) const override;
   };
 
   class ReplaceableClass : public Element
@@ -816,7 +828,7 @@ private:
     virtual bool isComponent() const override {return false;}
     virtual bool isExtend() const override {return false;}
     virtual bool isClass() const override {return true;}
-    virtual QString toString(bool skipTopLevel = false, bool mergeExtendsModifiers = false) const override;
+    virtual QString toString(bool skipTopLevel = false, bool mergeExtendsModifiers = false, bool includeComment = true) const override;
   };
 
   class Part
